==> haskell-text-builder-0.6.7-251-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-69SrkN81tl86NsbN8Hy2IM
key:                  text-builder-0.6.7-69SrkN81tl86NsbN8Hy2IM
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  af72233e0292810161095a8fd52db82c
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-69SrkN81tl86NsbN8Hy2IM
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-GSC61I1h20dKo6ThsUOPon

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.7-272-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-ClJcSXCDMO7341A8pS3sNv
key:                  text-builder-0.6.7-ClJcSXCDMO7341A8pS3sNv
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  ea584e320dc0b548a55567c439f900b1
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-ClJcSXCDMO7341A8pS3sNv
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-DJV168DOadm5lU3LIqtmjo

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
